@@ -471,7 +471,7 @@ _giraffe_bias_compute_mean(GiBiasResults* results, const cpl_image* image,
 
     cxint j, l, k;
     cxint img_dimx, img_dimy;
-    cxint ba_num_cols;
+    /*cxint ba_num_cols;*/
     cxint ba_num_rows;
     cxint curriter = 0;
     cxint x0, x1, x2, x3;
@@ -522,7 +522,7 @@ _giraffe_bias_compute_mean(GiBiasResults* results, const cpl_image* image,
         return -1;
     }
 
-    ba_num_cols = cpl_matrix_get_ncol(areas);
+    /*ba_num_cols = cpl_matrix_get_ncol(areas);*/
     ba_num_rows = cpl_matrix_get_nrow(areas);
 
     for (j = 0; j < ba_num_rows; j++) {
@@ -3355,6 +3355,7 @@ giraffe_bias_remove(GiImage* result, const GiImage* raw,
 
         // FIXME:
         //  Is this really needed? Disabled on request of DFO (RP)
+        //  If it has to be put back use giraffe_propertylist_get_conad()!
 #if 0
         if (cpl_propertylist_has(properties, GIALIAS_CONAD)) {
             cxdouble conad = cpl_propertylist_get_double(properties, GIALIAS_CONAD);
