@@ -33,6 +33,7 @@
 
 #include <cxslist.h>
 #include <cxstrutils.h>
+#include <cxmessages.h>
 
 #include <cpl_array.h>
 #include <cpl_propertylist.h>
@@ -84,8 +85,8 @@ _giraffe_fov_create_cube(const GiImage* spectra,
     cxdouble wmin = 0.;
     cxdouble wmax = 0.;
     cxdouble wstep = 0.;
-    cxdouble fstart = 1.;
-    cxdouble fend = 1.;
+    /*cxdouble fstart = 1.;*/
+    /*cxdouble fend = 1.;*/
 
     cpl_propertylist* properties = giraffe_image_get_properties(spectra);
 
@@ -140,7 +141,7 @@ _giraffe_fov_create_cube(const GiImage* spectra,
 
 
             first  = ceil(pixel);
-            fstart = pixel - first;
+            /*fstart = pixel - first;*/
 
         }
 
@@ -150,7 +151,7 @@ _giraffe_fov_create_cube(const GiImage* spectra,
 
 
             last = floor(pixel);
-            fend = pixel - last;
+            /*fend = pixel - last;*/
 
         }
 
@@ -898,7 +899,7 @@ giraffe_fov_build(GiFieldOfView* result, GiRebinning* rebinning,
                         cpl_msg_debug(fctid, "Unused IFU button detected. "
                                         "Skipping sub-slit %d", nss);
 
-                        cpl_array_erase_window(ssn, i, 1);
+                        cpl_array_set_invalid(_ssn, i);
 
                         cx_slist_push_back(simages, NULL);
                         cx_slist_push_back(eimages, NULL);
@@ -910,6 +911,34 @@ giraffe_fov_build(GiFieldOfView* result, GiRebinning* rebinning,
 
             }
 
+
+            /*
+             * Extract valid subslit indices from the index array
+             */
+
+            if (cpl_array_count_invalid(_ssn) > 0) {
+
+                cxint j = 0;
+                cxint k = 0;
+
+                cpl_array_set_size(ssn, cpl_array_get_size(ssn) -
+                                   cpl_array_count_invalid(_ssn));
+
+                for (k = 0; k < cpl_array_get_size(_ssn); ++k) {
+
+                    cxint invalid = 1;
+
+                    register cxint idx = cpl_array_get_int(_ssn, k, &invalid);
+
+                    if (!invalid) {
+                        cpl_array_set_int(ssn, j, idx);
+                        ++j;
+                    }
+
+                }
+
+            }
+
             cpl_array_delete(_ssn);
             _ssn = NULL;
 
@@ -1664,7 +1693,7 @@ giraffe_fov_save_cubes_eso3d(const GiFieldOfView* self,
 
     /* Currently not used. Set to avoid compiler warnings */
 
-    data = NULL;
+    (void) data;
 
 
     if ((self == NULL) || (properties == NULL) || (filename == NULL)) {
