@@ -45,6 +45,7 @@
 #include "giarray.h"
 #include "gimessages.h"
 #include "giastroutils.h"
+#include "giutils.h"
 #include "gifxcalibration.h"
 
 
@@ -1527,7 +1528,6 @@ giraffe_calibrate_flux(GiResponse* result, const GiRebinning* spectra,
     cxint i = 0;
     cxint status = 0;
     cxint nw = 0;
-    cxint ns = 0;
 
     const cxdouble* rdata = NULL;
 
@@ -1551,6 +1551,7 @@ giraffe_calibrate_flux(GiResponse* result, const GiRebinning* spectra,
     cpl_table* _flux = NULL;
     cpl_table* efficiency = NULL;
 
+    (void) flat;  /* Not used. */
 
     if (result == NULL) {
         return -1;
@@ -1609,8 +1610,6 @@ giraffe_calibrate_flux(GiResponse* result, const GiRebinning* spectra,
         cpl_table* _fibers = giraffe_table_get(fibers);
 
 
-        ns = cpl_image_get_size_x(_spectra);
-
         sky_spectrum = _giraffe_compute_mean_sky(_spectra, _fibers);
 
         if (sky_spectrum == NULL) {
@@ -1660,10 +1659,11 @@ giraffe_calibrate_flux(GiResponse* result, const GiRebinning* spectra,
 
 
     exptime = cpl_propertylist_get_double(properties, GIALIAS_EXPTIME);
-    conad = cpl_propertylist_get_double(properties, GIALIAS_CONAD);
     wlstep = cpl_propertylist_get_double(properties, GIALIAS_BINSTEP);
     wlstart = cpl_propertylist_get_double(properties, GIALIAS_BINWLMIN);
 
+    conad = giraffe_propertylist_get_conad(properties);
+
 
     /*
      * Convert the observed spectrum from ADU to e- / s / nm
