@@ -504,7 +504,12 @@ giraffe_image_load_properties(GiImage *self, const cxchar *filename,
         self->properties = NULL;
     }
 
-    self->properties = cpl_propertylist_load(filename, position);
+    /*
+     * Strip comments during load
+     */
+
+    self->properties = cpl_propertylist_load_regexp(filename, position,
+                                                    "^COMMENT$", TRUE);
 
     if (self->properties == NULL) {
         return 1;
