@@ -914,7 +914,7 @@ giraffe_linedata_writer(const GiLineData* self, cpl_propertylist* properties,
 
 
     /* Unused */
-    data = NULL;
+    (void) data;
 
     if (self == NULL || properties == NULL || filename == NULL) {
         return -1;
@@ -941,6 +941,10 @@ giraffe_linedata_writer(const GiLineData* self, cpl_propertylist* properties,
     giraffe_error_pop();
 
 
+    cpl_propertylist_erase(properties, "BSCALE");
+    cpl_propertylist_erase(properties, "BZERO");
+    cpl_propertylist_erase(properties, "BUNIT");
+
     /* FIXME: Workaround for CPL deficiency. World coordinate
      *        keywords are not removed from table headers.
      */
@@ -950,6 +954,10 @@ giraffe_linedata_writer(const GiLineData* self, cpl_propertylist* properties,
     cpl_propertylist_erase_regexp(properties, "^CDELT[0-9]$", 0);
     cpl_propertylist_erase_regexp(properties, "^CTYPE[0-9]$", 0);
 
+    cpl_propertylist_erase_regexp(properties, "^DATA(MIN|MAX)", 0);
+
+    cpl_propertylist_erase(properties, "EXTNAME");
+
 
     cpl_propertylist_update_string(properties, GIALIAS_WSOL_LMNAME,
                                    self->model);
