@@ -251,7 +251,7 @@ giraffe_chebyshev_base2d(cxdouble xstart, cxdouble ystart, cxdouble xsize,
 
     register cxint32 i, j, k, l;
 
-    cxint32 x_nrow, y_nrow, t_nrow, t_ncol;
+    cxint32 x_nrow, y_nrow, /*t_nrow,*/ t_ncol;
 
     register cxdouble dxsize2, d2xsize;
     register cxdouble dysize2, d2ysize;
@@ -285,7 +285,7 @@ giraffe_chebyshev_base2d(cxdouble xstart, cxdouble ystart, cxdouble xsize,
         return NULL;
     }
 
-    t_nrow = cpl_matrix_get_nrow(m_t);
+    /*t_nrow = cpl_matrix_get_nrow(m_t);*/
     t_ncol = cpl_matrix_get_ncol(m_t);
 
     pmx = cpl_matrix_get_data(m_x);
@@ -528,6 +528,7 @@ giraffe_chebyshev_fit1d(cxdouble start, cxdouble size, cpl_matrix *m_c,
     m_f = cpl_matrix_new(c_nrow, x_nrow);
 
     if (m_f == NULL) {
+        cpl_matrix_delete(m_t);
         return NULL;
     }
 
