@@ -67,7 +67,7 @@ _giraffe_tiny(cxdouble a)
     return a < 0. ? (a > -1.e-30) : (a < 1.e-30);
 }
 
-
+#ifdef GIRAFFE_USE_giraffe_matrix_gausspiv
 /*
  * @brief  matrix_gausspiv
  *
@@ -173,9 +173,9 @@ _giraffe_matrix_gausspiv(cxdouble *ptra, cxdouble *ptrc, cxint n)
 
     return 1;
 }
+#endif /* GIRAFFE_USE_giraffe_matrix_gausspiv */
 
-
-static cpl_matrix *
+/*static cpl_matrix *
 _giraffe_matrix_inverse(cpl_matrix *aa)
 {
     cxint test = 1;
@@ -214,7 +214,7 @@ _giraffe_matrix_inverse(cpl_matrix *aa)
     }
 
     return bb;
-}
+}*/
 
 
 /**
@@ -849,7 +849,7 @@ giraffe_matrix_dump(const cpl_matrix *matrix, cxint max_rows)
     cxint k;
     cxint nc;
     cxint nr;
-    cxint ncw;
+    /*cxint ncw;*/
 
     const cxdouble *pd_m = NULL;
 
@@ -874,7 +874,7 @@ giraffe_matrix_dump(const cpl_matrix *matrix, cxint max_rows)
 
     /* print header */
     for (i = 0; i < nc; i++) {
-        ncw = cx_string_sprintf(tmp, "      %d", i);
+        /*ncw =*/ cx_string_sprintf(tmp, "      %d", i);
         cx_string_append(buffer, cx_string_get(tmp));
     }
 
@@ -882,9 +882,9 @@ giraffe_matrix_dump(const cpl_matrix *matrix, cxint max_rows)
 
     /* print values */
     for (k = 0, i = 0; i < nr; i++) {
-        ncw = cx_string_sprintf(buffer,"  %d", i);
+        /*ncw =*/ cx_string_sprintf(buffer,"  %d", i);
         for (j = 0; j < nc; j++, k++) {
-            ncw = cx_string_sprintf(tmp, " %+18.12f", pd_m[k]);
+            /*ncw =*/ cx_string_sprintf(tmp, " %+18.12f", pd_m[k]);
             cx_string_append(buffer, cx_string_get(tmp));
         }
 
