@@ -775,8 +775,15 @@ cxint giraffe_psfdata_load(GiPsfData* self, const cxchar* filename)
 
         if ((cpl_image_get_size_x(buffer) != self->nfibers) ||
             (cpl_image_get_size_y(buffer) != self->nbins)) {
-                _giraffe_psfdata_clear(self);
-            return 2;
+
+            cpl_image_delete(buffer);
+            buffer = NULL;
+
+            _giraffe_psfdata_clear(self);
+
+                cpl_image_delete(buffer);
+                buffer = NULL;
+                return 2;
         }
         else {
 
@@ -833,7 +840,7 @@ giraffe_psfdata_save(const GiPsfData* self, cpl_propertylist* properties,
 
 
     /* Unused */
-    data = NULL;
+    (void) data;
 
     if (self == NULL || properties == NULL || filename == NULL) {
         return -1;
@@ -852,8 +859,20 @@ giraffe_psfdata_save(const GiPsfData* self, cpl_propertylist* properties,
     cpl_propertylist_update_int(properties, GIALIAS_PSFNS,
                                 self->nfibers);
 
+    cpl_propertylist_erase(properties, "BSCALE");
+    cpl_propertylist_erase(properties, "BZERO");
+    cpl_propertylist_erase(properties, "BUNIT");
+
+    cpl_propertylist_erase_regexp(properties, "^CRPIX[0-9]$", 0);
+    cpl_propertylist_erase_regexp(properties, "^CRVAL[0-9]$", 0);
+    cpl_propertylist_erase_regexp(properties, "^CDELT[0-9]$", 0);
+    cpl_propertylist_erase_regexp(properties, "^CTYPE[0-9]$", 0);
+
+    cpl_propertylist_erase_regexp(properties, "^DATA(MIN|MAX)", 0);
+
     giraffe_error_push();
 
+
     cpl_image_save(NULL, filename, CPL_BPP_IEEE_FLOAT,
                    properties, CPL_IO_DEFAULT);
 
