@@ -34,6 +34,8 @@
 #include <string.h>
 
 #include <cxtypes.h>
+#include <cxmemory.h>
+#include <cxstrutils.h>
 
 #include <cpl_matrix.h>
 
@@ -78,301 +80,254 @@ static const cxdouble RV_DAS2R =
     4.8481368110953599358991410235794797595635330237270e-6; /* pi/(180*3600) */
 
 
-/*
- * Slalib functions
- */
-
-/*
- *  - - - - - - - - - -
- *   s l a D e u l e r
- *  - - - - - - - - - -
- *
- *  Form a rotation matrix from the Euler angles - three successive
- *  rotations about specified Cartesian axes.
- *
- *  (double precision)
- *
- *  Given:
- *    *order char     specifies about which axes the rotations occur
- *    phi    double   1st rotation (radians)
- *    theta  double   2nd rotation (   "   )
- *    psi    double   3rd rotation (   "   )
- *
- *  Returned:
- *    Matrix   rmat  rotation matrix
- *
- *  A rotation is positive when the reference frame rotates
- *  anticlockwise as seen looking towards the origin from the
- *  positive region of the specified axis.
- *
- *  The characters of order define which axes the three successive
- *  rotations are about.  A typical value is 'zxz', indicating that
- *  rmat is to become the direction cosine matrix corresponding to
- *  rotations of the reference frame through phi radians about the
- *  old z-axis, followed by theta radians about the resulting x-axis,
- *  then psi radians about the resulting z-axis.
- *
- *  The axis names can be any of the following, in any order or
- *  combination:  x, y, z, uppercase or lowercase, 1, 2, 3.  Normal
- *  axis labelling/numbering conventions apply;  the xyz (=123)
- *  triad is right-handed.  Thus, the 'zxz' example given above
- *  could be written 'zxz' or '313' (or even 'zxz' or '3xz').  Order
- *  is terminated by length or by the first unrecognized character.
- *
- *  Fewer than three rotations are acceptable, in which case the later
- *  angle arguments are ignored.  Zero rotations leaves rmat set to the
- *  identity matrix.
- *
- *  Last revision:   9 December 1996
- *
- *  Copyright P.T.Wallace.  All rights reserved.
- */
-
-inline static void
-slaDeuler(const cxchar* order, cxdouble phi, cxdouble theta, cxdouble psi,
-          cpl_matrix* rmat)
-{
-    register cxint j, i, l, n, k;
-    cxdouble result[3][3], rotn[3][3], angle, s, c , w, wm[3][3];
-    cxchar axis;
-
-    /* Initialize result matrix */
-    for ( j = 0; j < 3; j++ ) {
-        for ( i = 0; i < 3; i++ ) {
-            result[i][j] = ( i == j ) ? 1.0 : 0.0;
-        }
-    }
-
-    /* Establish length of axis string */
-    l = strlen ( order );
-
-    /* Look at each character of axis string until finished */
-    for ( n = 0; n < 3; n++ ) {
-        if ( n <= l ) {
-
-            /* Initialize rotation matrix for the current rotation */
-            for ( j = 0; j < 3; j++ ) {
-                for ( i = 0; i < 3; i++ ) {
-                    rotn[i][j] = ( i == j ) ? 1.0 : 0.0;
-                }
-            }
-
-            /* Pick up the appropriate Euler angle and take sine & cosine */
-            switch ( n ) {
-            case 0 :
-                angle = phi;
-                break;
-            case 1 :
-                angle = theta;
-                break;
-            default:
-                angle = psi;
-                break;
-            }
-            s = sin ( angle );
-            c = cos ( angle );
-
-            /* Identify the axis */
-            axis =  order[n];
-            if ( ( axis == 'X' ) || ( axis == 'x' ) || ( axis == '1' ) ) {
-
-                /* Matrix for x-rotation */
-                rotn[1][1] = c;
-                rotn[1][2] = s;
-                rotn[2][1] = -s;
-                rotn[2][2] = c;
-            }
-            else if ( ( axis == 'Y' ) || ( axis == 'y' ) || ( axis == '2' ) ) {
-
-                /* Matrix for y-rotation */
-                rotn[0][0] = c;
-                rotn[0][2] = -s;
-                rotn[2][0] = s;
-                rotn[2][2] = c;
-            }
-            else if ( ( axis == 'Z' ) || ( axis == 'z' ) || ( axis == '3' ) ) {
-
-                /* Matrix for z-rotation */
-                rotn[0][0] = c;
-                rotn[0][1] = s;
-                rotn[1][0] = -s;
-                rotn[1][1] = c;
-            }
-            else {
-
-                /* Unrecognized character - fake end of string */
-                l = 0;
-            }
-
-            /* Apply the current rotation (matrix rotn x matrix result) */
-            for ( i = 0; i < 3; i++ ) {
-                for ( j = 0; j < 3; j++ ) {
-                    w = 0.0;
-                    for ( k = 0; k < 3; k++ ) {
-                        w += rotn[i][k] * result[k][j];
-                    }
-                    wm[i][j] = w;
-                }
-            }
-            for ( j = 0; j < 3; j++ ) {
-                for ( i= 0; i < 3; i++ ) {
-                    result[i][j] = wm[i][j];
-                }
-            }
-        }
-    }
-
-    /* Copy the result */
-    for ( j = 0; j < 3; j++ ) {
-        for ( i = 0; i < 3; i++ ) {
-            cpl_matrix_set(rmat, i, j, result[i][j]);
-        }
-    }
-
-    return;
-
-}
-
-
 /*
  * @brief
- *  Calculates the matrix of general precession from ep0 to ep1
+ *   Generate a rotation matrix from a set of Euler angles
  *
- * @param ep0  Initial epoch of mean equator and equinox e.g., 1950.0
- * @param ep1  Final epoch of mean equator and equinox
+ * @param mode   List of axis to rotate about (intrinsic rotations).
+ * @param phi    Angle of the first rotation.
+ * @param theta  Angle of the second rotation.
+ * @param psi    Angle of the third rotation.
  *
  * @return
- *   The 3 x 3 matrix of general precession.
+ *   The function returns the created 3x3 rotation matrix, or @c NULL in case
+ *   an error occurs.
  *
- * Form the matrix of precession between two epochs, using the
- * model of Simon et al (1994), which is suitable for long
- * periods of time.
+ * The function creates a rotation matrix from the Euler angles @em phi,
+ * @em theta and @em psi, by applying three successive rotations of the
+ * respective angle about the cartesian axes given in the list @em mode.
  *
- * @notes
- *   -# The epochs are TDB (loosely ET) Julian epochs.
- *   -# The matrix is in the sense   v(ep1)  =  rmatp * v(ep0)
- *   -# The absolute accuracy of the model is limited by the
- *      uncertainty in the general precession, about 0.3 arcsec per
- *      1000 years.  The remainder of the formulation provides a
- *      precision of 1 mas over the interval from 1000AD to 3000AD,
- *      0.1 arcsec from 1000BC to 5000AD and 1 arcsec from
- *      4000BC to 8000AD.
+ * The rotations are intrinsic rotations and are carried out in the order
+ * the axes are given by @em mode. The axes designations which may appear
+ * in the list mode are 'x', 'y', and 'z' for the first, second, and third
+ * axis respectively.
  *
- * Reference:
- *  Simon, J. L., et al., 1994. Astron.Astrophys., 282, 663-683.
- *
- * Author:
- *  P. T. Wallace. 23 August 1994
+ * The angles are defined according to the right hand rule, i.e. they are
+ * positive if they represent a rotation which appears counter-clockwise
+ * when observed from a point on the positive part of the rotation axis, and
+ * they are negative for clockwise rotations.
  */
 
-inline static cpl_matrix*
-slaPrecession (cxdouble ep0, cxdouble ep1)
+inline static cpl_matrix *
+_giraffe_create_rotation(const cxchar *mode, cxdouble phi, cxdouble theta,
+                         cxdouble psi)
 {
 
-    cxdouble t = 0.;
-    cxdouble w = 0.;
-    cxdouble z = 0.;
-    cxdouble t0 = 0.;
-    cxdouble zeta = 0.;
-    cxdouble theta = 0.;
-    cxdouble tas2r = 0.;
+    cxint nrotations = strlen(mode);
 
-    cpl_matrix* mprec = NULL;
+    cpl_matrix *self = cpl_matrix_new(3, 3);
 
 
-   /*
-    * Interval between basic epoch J2000.0 and beginning epoch (1000JY)
-    */
-
-    t0 = ( ep0 - 2000.0 ) / 1000.0;
+    nrotations = nrotations <= 3 ? nrotations : 3;
 
 
-   /*
-    * Interval over which precession required (1000JY)
-    */
+    /*
+     * Initialize the rotation matrix as identity
+     */
 
-    t =  ( ep1 - ep0 ) / 1000.0;
+    cpl_matrix_fill_diagonal(self, 1., 0);
 
 
-   /*
-    * Euler angles
-    */
+    /*
+     * Create the general rotation matrix by successively left
+     * multiplying the rotation matrices about the given axes.
+     */
 
-    tas2r = t * RV_DAS2R;
-    w = 23060.9097 +
-        (139.7459 +
-         (-0.0038 +
-          (-0.5918 +
-           (-0.0037 +
-            0.0007 * t0) * t0) * t0) * t0) * t0;
+    if (nrotations > 0) {
 
-    zeta = (w +
-            (30.2226 +
-             (-0.2523 +
-              (-0.3840 +
-               (-0.0014 +
-                0.0007 * t0) * t0) * t0) * t0 +
-             (18.0183 +
-              (-0.1326 +
-               (0.0006 +
-                0.0005 * t0) * t0) * t0 +
-              (-0.0583 +
-               (-0.0001 +
-                0.0007 * t0) * t0 +
-               (-0.0285 +
-                -0.0002 * t) * t) * t) * t) * t) * tas2r;
+        const cxchar *_mode = cx_strlower(cx_strdup(mode));
 
-    z = (w +
-         (109.5270 +
-          (0.2446 +
-           (-1.3913 +
-            (-0.0134 +
-             0.0026 * t0) * t0) * t0) * t0 +
-          (18.2667 +
-           (-1.1400 +
-            (-0.0173 +
-             0.0044 * t0) * t0) * t0 +
-           (-0.2821 +
-            (-0.0093 +
-             0.0032 * t0) * t0 +
-            (-0.0301 +
-             0.0006 * t0 +
-             -0.0001 * t) * t) * t) * t) * t) * tas2r;
+        register cxint i = 0;
 
-    theta = (20042.0207 +
-             (-85.3131 +
-              (-0.2111 +
-               (0.3642 +
-                (0.0008 +
-                 -0.0005 * t0) * t0) * t0) * t0) * t0 +
-             (-42.6566 +
-              (-0.2111 +
-               (0.5463 +
-                (0.0017 +
-                 -0.0012 * t0) * t0) * t0) * t0 +
-              (-41.8238 +
-               (0.0359 +
-                (0.0027 +
-                 -0.0001 * t0) * t0) * t0 +
-               (-0.0731 +
-                (0.0019 +
-                 0.0009 * t0) * t0 +
-                (-0.0127 +
-                 0.0011 * t0 + 0.0004 * t) * t) * t) * t) * t) * tas2r;
+        cpl_matrix *R = cpl_matrix_new(3, 3);
+
+        cxdouble angle[3] = {phi, theta, psi};
+        cxdouble *_R = cpl_matrix_get_data(R);
 
 
-   /*
-    * Rotation matrix
-    */
+        for (i = 0; i < nrotations; ++i) {
 
-    mprec = cpl_matrix_new(3, 3);
-    slaDeuler("ZYZ", -zeta, theta, -z, mprec);
+            cxdouble sa = sin(angle[i]);
+            cxdouble ca = cos(angle[i]);
 
-    return mprec;
+            cpl_matrix *mt = NULL;
+
+
+            cpl_matrix_fill(R, 0.);
+
+            switch (_mode[i]) {
+                case 'x':
+                {
+                    _R[0] =  1.;
+                    _R[4] =  ca;
+                    _R[5] =  sa;
+                    _R[7] = -sa;
+                    _R[8] =  ca;
+                    break;
+                }
+
+                case 'y':
+                {
+                    _R[0] =  ca;
+                    _R[2] = -sa;
+                    _R[4] =  1.;
+                    _R[6] =  sa;
+                    _R[8] =  ca;
+                    break;
+                }
+
+                case 'z':
+                {
+                    _R[0] =  ca;
+                    _R[1] =  sa;
+                    _R[3] = -sa;
+                    _R[4] =  ca;
+                    _R[8] =  1.;
+                    break;
+                }
+
+                default:
+                {
+                    /* Invalid axis designation */
+
+                    cpl_matrix_delete(R);
+                    cpl_matrix_delete(self);
+
+                    cx_free((cxchar*)_mode);
+
+                    return NULL;
+                    break;
+                }
+
+            }
+
+            mt = cpl_matrix_product_create(R, self);
+
+            cpl_matrix_delete(self);
+            self = mt;
+
+        }
+
+        cpl_matrix_delete(R);
+        cx_free((cxchar *)_mode);
+
+    }
+
+    return self;
 
 }
 
 
+/**
+ * @brief
+ *   Generate the matrix of precession between two epochs.
+ *
+ * @param epoch1  Initial fixed epoch
+ * @param epoch2  Epoch of the date
+ *
+ * @return
+ *   The matrix of general precession
+ *
+ * The function generates the 3 x 3 precession matrix from an arbitrary, fixed
+ * start epoch @em epoch1 to the epoch of date @em epoch2, using the
+ * model of Simon et al. (1994), which is suitable for long periods of time.
+ *
+ * The function is modeled following the idea of the slalib routine slPREL
+ * (P. T. Wallace / Starlink, 23 August 1996). The code is based on the
+ * constants and formulae given in Simon et al. (cf. example code prcupd.f)
+ *
+ * Reference:
+ *   Simon, J. L., et al., 1994 A&A 282, 663
+ */
+
+inline static cpl_matrix *
+_giraffe_precession_matrix(cxdouble epoch0, cxdouble epoch1)
+{
+
+    /*
+     * Variable names follow the notation of Simon et al.
+     */
+
+    const cxdouble sigma0 = 2000.;    /* The basic epoch of J2000 */
+    const cxdouble sigmaF = epoch0;   /* The arbitrary fixed epoch */
+    const cxdouble sigmaD = epoch1;   /* The epoch of the date */
+
+    /*
+     *  Time differences between the given epochs, in units of 1000 years:
+     *
+     *  JD(sigmaF) - JD(sigma0) / 365250.
+     *  JD(sigmaD) - JD(sigmaF) / 365250.
+     */
+
+    const cxdouble T = (sigmaF - sigma0) / 1000.;
+    const cxdouble t = (sigmaD - sigmaF) / 1000.;
+
+
+    cpl_matrix *mprc = NULL;
+
+    cxdouble thetaA = RV_DAS2R;
+    cxdouble zetaA  = RV_DAS2R;
+    cxdouble zA     = RV_DAS2R;
+
+    cxdouble T2 = T  * T;
+    cxdouble T3 = T2 * T;
+    cxdouble T4 = T3 * T;
+    cxdouble T5 = T4 * T;
+
+    cxdouble t2 = t  * t;
+    cxdouble t3 = t2 * t;
+    cxdouble t4 = t3 * t;
+    cxdouble t5 = t4 * t;
+    cxdouble t6 = t5 * t;
+
+
+    /*
+     * Compute the Euler angles (in units of radians)
+     *
+     * The constants in the following are the constants given in the example
+     * code prcupd.f of Simon et al. (1994) converted to units of arcsec
+     * (the constants in the example are given in units of 1/10000 arcsec).
+     */
+
+
+    thetaA *= (20042.0207 - 85.3131 * T - 0.2111  * T2 + 0.3642  * T3 +
+               0.0008  * T4 -0.0005  * T5) * t +
+              (-42.6566 - 0.2111 * T + 0.5463 * T2 + 0.0017 * T3 -
+               0.0012 * T4) * t2 +
+              (-41.8238 + 0.0359 * T + 0.0027 * T2 - 0.0001 * T3) * t3 +
+              (-0.0731 + 0.0019 * T + 0.0009 * T2) * t4 +
+              (-0.0127 + 0.0011 * T) * t5 +
+              (0.0004) * t6;
+
+    zetaA *= (23060.9097 + 139.7495 * T - 0.0038 * T2 - 0.5918 * T3 -
+              0.0037 * T4 + 0.0007 * T5) * t +
+             (30.2226 - 0.2523 * T - 0.3840 * T2 - 0.0014 * T3 +
+              0.0007 * T4) * t2 +
+             (18.0183 - 0.1326 * T + 0.0006 * T2 + 0.0005 * T3) * t3 +
+             (-0.0583 - 0.0001 * T + 0.0007 * T2) * t4 +
+             (-0.0285) * t5 +
+             (-0.0002) * t6;
+
+    zA *= (23060.9097 + 139.7495 * T - 0.0038 * T2 - 0.5918 * T3 -
+           0.0037 * T4 + 0.0007 * T5) * t +
+          (109.5270 + 0.2446 * T - 1.3913 * T2 - 0.0134 * T3 +
+           0.0026 * T4) * t2 +
+          (18.2667 - 1.1400 * T - 0.0173 * T2 + 0.0044 * T3) * t3 +
+          (-0.2821 - 0.0093 * T + 0.0032 * T2) * t4 +
+          (-0.0301 + 0.0006 * T) * t5 +
+          (-0.0001) * t6;
+
+
+    /*
+     *  Create precession matrix
+     */
+
+    mprc = _giraffe_create_rotation("zyz", -zetaA, thetaA, -zA);
+
+    return mprc;
+
+}
+
 
 /*
  * @brief
@@ -1025,7 +980,7 @@ earth_velocity(cxdouble dje, cxdouble deq, cxdouble* const hvel,
 
         cxdouble deqdat = (dje - dct0 - dcbes) / dctrop + dc1900;
 
-        cpl_matrix* prec = slaPrecession(deqdat, deq);
+        cpl_matrix* prec = _giraffe_precession_matrix(deqdat, deq);
 
 
         for (n = 0; n < 3; n++) {
@@ -1126,7 +1081,7 @@ giraffe_rvcorrection_compute(GiRvCorrection* rv,
     dc[1] = sin(_ra) * cos(_dec);
     dc[2] = sin(_dec);
 
-    precession = slaPrecession(equinox, eqt);
+    precession = _giraffe_precession_matrix(equinox, eqt);
 
     for (i = 0; i < 3; ++i) {
 
