@@ -1447,7 +1447,7 @@ _giraffe_compute_offsets(const GiImage* spectra, const GiTable* mask,
     }
 
     cpl_msg_debug(fctid, "Mask cleared from %d to %ld", k,
-                  _giraffe_sgmask_size(_mask) - 1);
+                  (long)(_giraffe_sgmask_size(_mask) - 1));
 
 
     /*
@@ -1560,7 +1560,7 @@ _giraffe_compute_offsets(const GiImage* spectra, const GiTable* mask,
         cxdouble avsigma = 0.;
         cxdouble fx = 0.;
         cxdouble fxtotal = 0.;
-        cxdouble fxaverage = 0.;
+        /*cxdouble fxaverage = 0.;*/
         cxdouble fxmask = 0.;
         cxdouble sum = 0.;
         cxdouble position = 0.;
@@ -1599,7 +1599,7 @@ _giraffe_compute_offsets(const GiImage* spectra, const GiTable* mask,
         }
 
         fx /= sampling;
-        fxaverage = fxtotal / fxmask;
+        /*fxaverage = fxtotal / fxmask;*/
 
         if (fx > 0.) {
             avsigma = 1. / sqrt(fx);
