@@ -45,6 +45,7 @@
 
 #include "gialias.h"
 #include "gimessages.h"
+#include "gierror.h"
 #include "giutils.h"
 
 
@@ -617,8 +618,65 @@ giraffe_add_frameset_info(cpl_propertylist *plist, const cpl_frameset *set,
             switch (group) {
             case CPL_FRAME_GROUP_RAW:
             {
+
+                cxint status = 0;
+
                 ++nraw;
-                cxint status = _giraffe_add_frame_info(plist, base, tag,
+
+
+                /*
+                 * Get the product's ancestor as the archive name of the
+                 * first raw file in the reference set
+                 */
+
+                if (!cpl_propertylist_has(plist, GIALIAS_ANCESTOR)) {
+
+                    if (nraw == 1) {
+
+                        cpl_propertylist *_plist = cpl_propertylist_load(name, 0);
+
+                        if (_plist == NULL) {
+
+                            if (base != NULL) {
+                                cx_free((cxchar *)base);
+                            }
+
+                            cpl_frameset_iterator_delete(it);
+                            cx_string_delete(key);
+
+                            return -2;
+
+                        }
+
+                        if (cpl_propertylist_has(_plist, GIALIAS_ANCESTOR)) {
+                            cpl_propertylist_copy_property(plist, _plist,
+                                                           GIALIAS_ANCESTOR);
+                        }
+                        else {
+
+                            const cxchar *s =
+                                    cpl_propertylist_get_string(_plist,
+                                                                GIALIAS_ARCFILE);
+                            const cxchar *c = "Inherited archive file name "
+                                    "of the first raw data frame";
+
+                            if (s != NULL) {
+                                cpl_propertylist_append_string(plist,
+                                                               GIALIAS_ANCESTOR, s);
+                                cpl_propertylist_set_comment(plist,
+                                                             GIALIAS_ANCESTOR, c);
+                            }
+
+                        }
+
+                        cpl_propertylist_delete(_plist);
+
+                    }
+
+                }
+
+
+                status = _giraffe_add_frame_info(plist, base, tag,
                                                        sequence, nraw, 0);
 
                 if (status != 0) {
@@ -632,6 +690,7 @@ giraffe_add_frameset_info(cpl_propertylist *plist, const cpl_frameset *set,
                     return -2;
                 }
 
+
                 break;
             }
 
@@ -682,7 +741,7 @@ giraffe_add_frameset_info(cpl_propertylist *plist, const cpl_frameset *set,
                         cx_string_sprintf(md5, "%s%d %s%"
                                           CX_PRINTF_FORMAT_SIZE_TYPE "%s",
                                           "ESO PRO REC", sequence, "CAL",
-                                          ncalib, "DATAMD5");
+                                          ncalib, " DATAMD5");
 
                         status =
                             cpl_propertylist_update_string(plist,
@@ -1179,6 +1238,91 @@ giraffe_frameset_set_groups(cpl_frameset* set, GiGroupInfo *groups)
 }
 
 
+/**
+ * @brief
+ *   Retrieve the ADU to electrons conversion factor from the given properties.
+ *
+ * @param properties  The property list to search for the conversion factor.
+ *
+ * @return
+ *   The function returns the confersion factor in electrons/ADU. In case
+ *   an error occurred, zero is returned, and an appropriate error code is
+ *   set.
+ *
+ * @error
+ *   <table class="ec" align="center">
+ *     <tr>
+ *       <td class="ecl">CPL_ERROR_DATA_NOT_FOUND</td>
+ *       <td class="ecr">
+ *         Any of the required properties (conversion factor) was not found.
+ *       </td>
+ *     </tr>
+ *     <tr>
+ *       <td class="ecl">CPL_ERROR_ILLEGAL_INPUT</td>
+ *       <td class="ecr">
+ *         An invalid value (less than 0.) of the conversion factor was
+ *         encountered.
+ *       </td>
+ *     </tr>
+ *   </table>
+ * @enderror
+ *
+ * The function determines the ADU to electrons conversion factor from the
+ * properties @em properties.
+ */
+
+cxdouble giraffe_propertylist_get_conad(const cpl_propertylist* properties)
+{
+
+    const cxchar* const fctid = "giraffe_propertylist_get_conad";
+
+    const cxchar *names[2] = {GIALIAS_CONAD, GIALIAS_CONAD_LEGACY};
+    const cxchar *name = NULL;
+
+    cxdouble conad = 1.;
+
+
+    cx_assert(properties != NULL);
+
+
+    if (!cpl_propertylist_has(properties, GIALIAS_CONAD)) {
+
+        if (!cpl_propertylist_has(properties, GIALIAS_CONAD_LEGACY)) {
+
+            cpl_msg_error(fctid, "Missing detector gain property (%s, %s)! ",
+                      GIALIAS_CONAD, GIALIAS_CONAD_LEGACY);
+            cpl_error_set(fctid, CPL_ERROR_DATA_NOT_FOUND);
+
+            return 0.;
+
+        }
+        else {
+            name = names[1];
+        }
+
+
+    }
+    else {
+        name = names[0];
+    }
+
+    conad = cpl_propertylist_get_double(properties, name);
+
+    if (conad < 0.) {
+
+        cpl_msg_error(fctid, "Invalid conversion factor (%s) %.3g "
+                      "[e-/ADU]", name, conad);
+        cpl_error_set(fctid, CPL_ERROR_ILLEGAL_INPUT);
+
+        return 0.;
+
+    }
+
+    return conad;
+
+}
+
+
 /**
  * @brief
  *   Retrieve the read-out noise from the given properties.
@@ -1209,6 +1353,7 @@ giraffe_frameset_set_groups(cpl_frameset* set, GiGroupInfo *groups)
  * detector read-out noise property is taken. The conversion factor property
  * is used to convert the read-out noise from ADU into electrons, as necessary.
  */
+
 cxdouble
 giraffe_propertylist_get_ron(const cpl_propertylist* properties)
 {
@@ -1252,24 +1397,15 @@ giraffe_propertylist_get_ron(const cpl_propertylist* properties)
          * has to be converted into electrons.
          */
 
-        if (!cpl_propertylist_has(properties, GIALIAS_CONAD)) {
-            cpl_msg_error(fctid, "Missing detector gain property (%s)! ",
-                          GIALIAS_CONAD);
-            cpl_error_set(fctid, CPL_ERROR_DATA_NOT_FOUND);
+        giraffe_error_push();
 
+        conad = giraffe_propertylist_get_conad(properties);
+
+        if (cpl_error_get_code() != CPL_ERROR_NONE) {
             return 0.;
         }
-        else {
-            conad = cpl_propertylist_get_double(properties, GIALIAS_CONAD);
-        }
 
-        if (conad < 0.) {
-            cpl_msg_error(fctid, "Invalid conversion factor (%s) %.3g "
-                          "[e-/ADU]", GIALIAS_CONAD, conad);
-            cpl_error_set(fctid, CPL_ERROR_ILLEGAL_INPUT);
-
-            return 0.;
-        }
+        giraffe_error_pop();
 
         ron = cpl_propertylist_get_double(properties, GIALIAS_BIASSIGMA) *
                 conad;
