@@ -755,9 +755,9 @@ gimasterbias(cpl_parameterlist* config, cpl_frameset* set)
                 cpl_image_get_data_double_const(_master_bias);
 
 
-        cxint e_code2 = 0;
-        cxint row_min = 0;
-        cxint row_max = 0;
+        /*cxint e_code2 = 0;*/
+        /*cxint row_min = 0;*/
+        /*cxint row_max = 0;*/
         cxint ncol = cpl_image_get_size_x(_master_bias);
         cxint nrow = cpl_image_get_size_y(_master_bias);
         cxint* pi_bpm = NULL;
@@ -785,7 +785,7 @@ gimasterbias(cpl_parameterlist* config, cpl_frameset* set)
          * re-assign the properties' handle.
          */
 
-        e_code2 = giraffe_image_set_properties(bpixel, properties);
+        /*e_code2 =*/ giraffe_image_set_properties(bpixel, properties);
         properties = giraffe_image_get_properties(bpixel);
 
 
@@ -866,46 +866,36 @@ gimasterbias(cpl_parameterlist* config, cpl_frameset* set)
 
             if (cpl_propertylist_has(properties, GIALIAS_RON)) {
 
+                cxdouble conad = 1;
+
+
                 ron = cpl_propertylist_get_double(properties, GIALIAS_RON);
 
-                if (cpl_propertylist_has(properties, GIALIAS_CONAD)) {
-    
-                    cxdouble conad = cpl_propertylist_get_double(properties,
-                                                          GIALIAS_CONAD);
-    
-                    if (conad <= 0.) {
-    
-                        cpl_msg_error(fctid, "Invalid conversion factor "
-                                      "property (%s): %.2g!", GIALIAS_CONAD,
-                                      conad);
-    
-                        giraffe_image_delete(bpixel);
-                        bpixel = NULL;
-    
-                        giraffe_image_delete(master_bias);
-                        master_bias = NULL;
-    
-                        return -1;
-                    }
-                    else {
-                        ron /= conad;
-                    }
-                }
-                else {
-                    cpl_msg_error(fctid, "Missing conversion factor property "
-                            "(%s)!", GIALIAS_CONAD);
-    
+                giraffe_error_push();
+
+                conad = giraffe_propertylist_get_conad(properties);
+
+                if (cpl_error_get_code() != CPL_ERROR_NONE) {
+
                     giraffe_image_delete(bpixel);
                     bpixel = NULL;
-    
+
                     giraffe_image_delete(master_bias);
                     master_bias = NULL;
-    
+
                     return -1;
+
                 }
+
+                giraffe_error_pop();
+
+                ron /= conad;
+
             }
             else {
+
                 ron = cpl_image_get_stdev(giraffe_image_get(master_bias));
+
             }
             
         }
@@ -932,12 +922,12 @@ gimasterbias(cpl_parameterlist* config, cpl_frameset* set)
 
             if (median < median_min) {
                 median_min = median;
-                row_min = i;
+                /*row_min = i;*/
             }
 
             if (median > median_max) {
                 median_max = median;
-                row_max = i;
+                /*row_max = i;*/
             }
 
             tlow  = median - mbias_config.bpm.factor * ron;
