@@ -2084,7 +2084,7 @@ gistandard(cpl_parameterlist* config, cpl_frameset* set)
 
     if (status != 0) {
 
-        cpl_msg_error(_id, "Instrument resonse computation failed!");
+        cpl_msg_error(_id, "Instrument response computation failed!");
 
         giraffe_response_delete(response);
         response = NULL;
@@ -2494,7 +2494,8 @@ giqcstandard(cpl_frameset* set)
      * Write QC1 log and save updated product.
      */
 
-    _properties = cpl_propertylist_duplicate(properties);
+    _properties = cpl_propertylist_load_regexp(cpl_frame_get_filename(pframe),
+                                               0, "^COMMENT$", TRUE);
 
     cpl_propertylist_erase_regexp(_properties, "ESO QC.*", 0);
 
