@@ -2310,7 +2310,9 @@ giqcwavecalibration(cpl_frameset* set)
     }
 
 
-    properties = cpl_propertylist_load(cpl_frame_get_filename(pframe), 0);
+    properties = cpl_propertylist_load_regexp(cpl_frame_get_filename(pframe),
+                                              0, "^COMMENT$", TRUE);
+
     cx_assert(properties != NULL);
 
     if (cpl_propertylist_has(properties, GIALIAS_GRATWLEN) == FALSE) {
